const glob = require('glob');
const { promisify } = require('util');
const { join } = require('path');
const { rename, writeFile } = require('fs');
const wf = promisify(writeFile);
const config = require('./config.json');
const  { snakeCase } = require('change-case');

const generateStringLiterals = (literals) =>
    [
      `export type IconNames =`,
      `${literals.map(key => `  | '${key}'`).join('\n')};\n`
    ].join('\n');
  

const renameFilesAndGenerateTypes = async (dir) => {
    const literals = [];
    const globPath = join(dir, '**/*.svg');
    const files = await promisify(glob)(globPath, {});
  
    if (!files.length) {
      throw new Error(`No SVGs found in ${dir}`);
    }
    files.forEach((file) => {
        const connectedName = file.replace(/\s+/g, '');
        const pathArr = connectedName.split('/');
        const pathArrLength = pathArr.length;
        let oldFileName = pathArr.pop().replace('.svg', '');
        const folderName = pathArr.pop();
        let newFileName = pathArrLength > 2
            ? snakeCase(`${folderName}${oldFileName}`)
            : snakeCase(oldFileName);
        literals.push(newFileName);
        const newPath = file.replace(oldFileName, newFileName);
        rename(file , newPath, err => console.log(err));
        
    });

    const stringLiterals = generateStringLiterals(literals);
    await wf(`${config.outputDir}/iconNames.ts`, stringLiterals);
};
renameFilesAndGenerateTypes(config.inputDir);